Function to be applied over gMat to get p-values from survreg().
survregFn(x, xMat, leftTime2, rightTime2, p)A scalar p-value for testing the effect of the genotype in survreg() Weibull model.
n*1 genotype vector.
n*p matrix of non-genotype covariates.
n*1 vector of left interval times in the format of Surv() interval2 type, i.e NA for left or right censored observations.
n*1 vector of right interval times in the format of Surv() interval2 type, i.e NA for left or right censored observations.
scalar, number of columns in xMat.